import_dir

Function import_dir 

pub fn import_dir(dir: &Path) -> Vec<Imported>
Scan a directory for known version files and import them. The first file to mention a tool wins (specific files are scanned before broad ones).